@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -145,6 +145,19 @@ void SendLater::SendLaterUtil::reload()
     }
 }
 
+void SendLater::SendLaterUtil::removeItem(qint64 item)
+{
+    qCDebug(LIBSENDLATER_LOG) << " void SendLater::SendLaterUtil::removeItem()" << item;
+
+    QDBusInterface interface(serviceName(), dbusPath());
+    if (interface.isValid()) {
+        interface.call(QStringLiteral("removeItem"), item);
+    } else {
+        qCDebug(LIBSENDLATER_LOG) << " Can not remove item";
+    }
+}
+
+
 QString SendLater::SendLaterUtil::sendLaterPattern()
 {
     return QStringLiteral("SendLaterItem %1");
